@@ -24,11 +24,14 @@
 #include "file_dialog.h"
 #include "geonkick_button.h"
 #include "geonkick_slider.h"
+#include "PathListModel.h"
 
 #include <RkLabel.h>
 #include <RkLineEdit.h>
 #include <RkEvent.h>
 #include <RkPainter.h>
+#include <RkList.h>
+#include <RkContainer.h>
 
 RK_DECLARE_IMAGE_RC(open_active);
 RK_DECLARE_IMAGE_RC(save_active);
@@ -51,9 +54,9 @@ FilesView::FilesView(GeonkickWidget *parent)
         , scrollBar{nullptr}
         , isScrollBarVisible{false}
 {
-        setFixedSize(parent->width() - 20, parent->height() - 100);
+        setFixedSize(parent->width() - 110, parent->height() - 100);
         visibleLines = height() / (lineHeight + lineSacing);
-        setPosition(10, 50);
+        setPosition(104, 50);
         setBackgroundColor(50, 50, 50);
         setBorderColor(40, 40, 40);
         setBorderWidth(1);
@@ -70,7 +73,9 @@ std::string FilesView::getCurrentPath() const
 void FilesView::setCurrentPath(const std::string &path)
 {
         currentPath = path;
+        selectedFileIndex = -1;
         loadCurrentDirectory();
+        update();
 }
 
 void FilesView::createScrollBar()
@@ -184,7 +189,7 @@ void FilesView::loadCurrentDirectory()
         offsetIndex = 0;
         selectedFileIndex = 0;
         showScrollBar(filesList.size() > visibleLines);
-        currentPathChanged(currentPath.string());
+        action currentPathChanged(currentPath.string());
 }
 
 void FilesView::paintWidget(RkPaintEvent *event)
@@ -239,7 +244,7 @@ void FilesView::mouseButtonPressEvent(RkMouseEvent *event)
         if (event->button() == RkMouseEvent::ButtonType::WheelUp) {
                 onLineUp();
                 return;
-        } else if(event->button() == RkMouseEvent::ButtonType::WheelDown) {
+        } else if (event->button() == RkMouseEvent::ButtonType::WheelDown) {
                 onLineDown();
                 return;
         }
@@ -247,6 +252,9 @@ void FilesView::mouseButtonPressEvent(RkMouseEvent *event)
         auto line = getLine(event->x(), event->y());
         if (line > -1) {
                 selectedFileIndex = offsetIndex + line;
+                std::string file = getSelectedFile();
+                if (!std::filesystem::is_directory(file))
+                        action currentFileChanged(file);
                 update();
         }
 }
@@ -303,12 +311,21 @@ void FilesView::keyPressEvent(RkKeyEvent *event)
                 openSelectedFile();
 }
 
-void FilesView::openSelectedFile()
+std::string FilesView::getSelectedFile() const
 {
         if (!filesList.empty() && selectedFileIndex > -1
             && static_cast<decltype(filesList.size())>(selectedFileIndex) < filesList.size()
 	    && !filesList[selectedFileIndex].empty()) {
-                if (!std::filesystem::is_directory(filesList[selectedFileIndex]))
+                return filesList[selectedFileIndex];
+        }
+        return "";
+}
+
+void FilesView::openSelectedFile()
+{
+        std::string file = getSelectedFile();
+        if (!file.empty()) {
+                if (!std::filesystem::is_directory(file))
                         action openFile(filesList[selectedFileIndex].string());
                 else
                         loadCurrentDirectory();
@@ -356,20 +373,39 @@ void FilesView::setFilters(const std::vector<std::string> &filters)
         fileFilters = filters;
 }
 
-FileDialog::FileDialog(GeonkickWidget *parent, FileDialog::Type type, const std::string& title)
-        : GeonkickWidget(parent, Rk::WindowFlags::Dialog)
+FileDialog::FileDialog(GeonkickWidget *parent,
+                       FileDialog::Type type,
+                       const std::string& title)
+        : GeonkickWidget(parent, type == FileDialog::Type::Browse ? Rk::WindowFlags::Widget : Rk::WindowFlags::Dialog)
         , dialogType{type}
         , filesView{nullptr}
         , pathLabel{nullptr}
         , status{AcceptStatus::Cancel}
+        , shortcutDirectoriesModel{new PathListModel(this)}
+        , shortcutDirectoriesView{new RkList(this, shortcutDirectoriesModel)}
 {
         setTitle(title);
-
         setFixedSize(600, 400);
         filesView = new FilesView(this);
         RK_ACT_BIND(filesView, openFile, RK_ACT_ARGS(const std::string &), this, onAccept());
+        RK_ACT_BIND(filesView, currentFileChanged, RK_ACT_ARGS(const std::string &file),
+                    this, currentFileChanged(file));
         RK_ACT_BIND(filesView, currentPathChanged, RK_ACT_ARGS(const std::string &pathName),
                     this, onPathChanged(pathName));
+        RK_ACT_BIND(filesView, currentPathChanged, RK_ACT_ARGS(const std::string &pathName),
+                    this, directoryChanged(pathName));
+
+        RK_ACT_BIND(shortcutDirectoriesModel,
+                    itemSelected,
+                    RK_ACT_ARGS(RkModelItem item),
+                    filesView,
+                    setCurrentPath(std::get<std::string>(item.data(static_cast<int>(PathListModel::PathListDataType::Path)))));
+        shortcutDirectoriesView->setBorderColor(40, 40, 40);
+        shortcutDirectoriesView->setBorderWidth(1);
+        shortcutDirectoriesView->setBackgroundColor({50, 50, 50});
+        shortcutDirectoriesView->setPosition(0, filesView->y());
+        shortcutDirectoriesView->setSize(100 ,filesView->height());
+        shortcutDirectoriesView->show();
 
         pathLabel = new RkLabel(this, "Path: " + filesView->getCurrentPath());
         pathLabel->setBackgroundColor(background());
@@ -379,32 +415,37 @@ FileDialog::FileDialog(GeonkickWidget *parent, FileDialog::Type type, const std:
         pathLabel->setTextColor(textColor());
         pathLabel->show();
 
-        auto acceptButton = new GeonkickButton(this);
-        acceptButton->setFixedSize(90, 30);
-        acceptButton->setPosition(width() - acceptButton->width() - 10,
-                                  height() - acceptButton->height() - 5);
-        if (dialogType == Type::Save)
-                acceptButton->setUnpressedImage(RkImage(90, 30, RK_IMAGE_RC(save_active)));
-        else
-                acceptButton->setUnpressedImage(RkImage(90, 30, RK_IMAGE_RC(open_active)));
-        RK_ACT_BIND(acceptButton, toggled, RK_ACT_ARGS(bool pressed), this, onAccept());
-        acceptButton->show();
+        auto buttomContainer = new RkContainer(this);
+        buttomContainer->setSize({width(), 30});
+        buttomContainer->setPosition({5, height() - buttomContainer->height() - 5});
 
-        auto cancelButton = new GeonkickButton(this);
-        cancelButton->setFixedSize(90, 30);
-        cancelButton->setPosition(acceptButton->x() - cancelButton->width() - 5, acceptButton->y());
-        cancelButton->setUnpressedImage(RkImage(90, 30, RK_IMAGE_RC(cancel)));
-        RK_ACT_BIND(cancelButton, toggled, RK_ACT_ARGS(bool pressed), this, onCancel());
-        cancelButton->show();
+        if (dialogType != Type::Browse) {
+                auto acceptButton = new GeonkickButton(this);
+                acceptButton->setFixedSize(90, 30);
+                if (dialogType == Type::Save)
+                        acceptButton->setUnpressedImage(RkImage(90, 30, RK_IMAGE_RC(save_active)));
+                else
+                        acceptButton->setUnpressedImage(RkImage(90, 30, RK_IMAGE_RC(open_active)));
+                RK_ACT_BIND(acceptButton, toggled, RK_ACT_ARGS(bool pressed), this, onAccept());
+                acceptButton->show();
+                buttomContainer->addSpace(10, Rk::Alignment::AlignRight);
+                buttomContainer->addWidget(acceptButton, Rk::Alignment::AlignRight);
+                auto cancelButton = new GeonkickButton(this);
+                cancelButton->setFixedSize(90, 30);
+                cancelButton->setUnpressedImage(RkImage(90, 30, RK_IMAGE_RC(cancel)));
+                RK_ACT_BIND(cancelButton, toggled, RK_ACT_ARGS(bool pressed), this, onCancel());
+                cancelButton->show();
+                buttomContainer->addSpace(5);
+                buttomContainer->addWidget(cancelButton, Rk::Alignment::AlignRight);
+        }
 
         if (dialogType == Type::Save) {
                 fileNameEdit = new RkLineEdit(this);
                 fileNameEdit->setFont(font());
-                fileNameEdit->setSize(cancelButton->x() - 20, 20);
-                fileNameEdit->setX(filesView->x());
-                fileNameEdit->setY(cancelButton->y() + (cancelButton->height() - fileNameEdit->height()) / 2);
+                fileNameEdit->setSize(width() - 200, 20);
                 fileNameEdit->show();
                 RK_ACT_BIND(fileNameEdit, enterPressed, RK_ACT_ARGS(), this, onAccept());
+                buttomContainer->addWidget(fileNameEdit);
         }
 
         show();
@@ -419,20 +460,35 @@ void FileDialog::onPathChanged(const std::string &pathName)
 void FileDialog::onAccept()
 {
         status = AcceptStatus::Accept;
-        if (dialogType == Type::Open && !filesView->selectedFile().empty()) {
-                pathSelected = filesView->selectedFile();
-                action selectedFile(pathSelected);
-                close();
-        } else {
-                if (!fileNameEdit->text().empty()) {
-                        pathSelected = filesView->getCurrentPath() / std::filesystem::path(fileNameEdit->text());
-                        action selectedFile(pathSelected);
-                        close();
-                } else if (!filesView->selectedFile().empty() && !std::filesystem::is_directory(filesView->selectedFile())) {
+        switch (dialogType) {
+        case Type::Open:
+                if (!filesView->selectedFile().empty()) {
                         pathSelected = filesView->selectedFile();
                         action selectedFile(pathSelected);
                         close();
                 }
+                break;
+        case Type::Save:
+                if (!fileNameEdit->text().empty()) {
+                        pathSelected = filesView->getCurrentPath()
+                                / std::filesystem::path(fileNameEdit->text());
+                        action selectedFile(pathSelected);
+                        close();
+                } else if (!filesView->selectedFile().empty()
+                           && !std::filesystem::is_directory(filesView->selectedFile())) {
+                        pathSelected = filesView->selectedFile();
+                        action selectedFile(pathSelected);
+                        close();
+                }
+                break;
+        case Type::Browse:
+                if (!filesView->selectedFile().empty()) {
+                        pathSelected = filesView->selectedFile();
+                        action selectedFile(pathSelected);
+                }
+                break;
+        default:
+                return;
         }
 }
 
@@ -445,7 +501,7 @@ void FileDialog::onCancel()
 void FileDialog::closeEvent(RkCloseEvent *event)
 {
         status = AcceptStatus::Cancel;
-        close();
+        RkWidget::closeEvent(event);
 }
 
 std::string FileDialog::currentDirectory() const
@@ -472,3 +528,8 @@ void FileDialog::setFilters(const std::vector<std::string> &filters)
 {
         filesView->setFilters(filters);
 }
+
+void FileDialog::setHomeDirectory(const std::string &path)
+{
+        shortcutDirectoriesModel->setHomeDirectory(path);
+}
